@@ -131,11 +131,7 @@ class Document:
 
 
     def lemmas(self):
-        for word in self.stanza_words:
-            if word and word.lemma:
-                self.__lemmas.append(word.lemma.replace("_", ""))
-            else:
-                self.__lemmas.append("X")
+        self.__lemmas = [word.lemma.replace("_", "") if word and word.lemma else "X" for word in self.stanza_words]
 
 
     def get_lemma(self) -> str:
@@ -143,7 +139,7 @@ class Document:
 
 
     def words(self):
-        for word in self.stanza_words: self.__words.append(word.text)
+        self.__words = [word.text for word in self.stanza_words]
 
 
     def get_words(self) -> str:
@@ -151,13 +147,7 @@ class Document:
 
 
     def pos_tags(self):
-        for word in self.stanza_words:
-            if word and word.xpos and word.xpos != "_":
-                self.__pos_tags.append(word.xpos)
-            elif word.xpos == "_":
-                self.__pos_tags.append("X")
-            else:
-                self.__pos_tags.append("X")
+        self.__pos_tags = [word.xpos if word and word.xpos and word.xpos != "_" else "X" if word.xpos == "_" else "X" for word in self.stanza_words]
 
 
     def get_pos_tags(self) -> str:
@@ -206,7 +196,6 @@ class Document:
 
 
     def addresses(self):
-        print("Hakkan aadresse otsima")
         text = self.get_words()
         addresses = AddressParser(text, self.stanza_entities, self.dominant_language_code).parse()
         self.__texta_facts.extend((addr.to_fact(Document.FACT_NAME_ADDRESS, self.doc_path) for addr in addresses))
@@ -408,7 +397,8 @@ class Document:
         """
         if first_spans[1] > 15:  # s@yandex.ru > : Hello, Steven! | l@gmail.com :\nHello, Stephanie!
             text_between = text[first_spans[1] - 15:second_spans[0]]
-            if re.search("\p{L}@\p{L}{3,10}\.\p{L}{2,3} {0,2}>? ?:\s", text_between):
+            pat = re.compile("\p{L}@\p{L}{3,10}\.\p{L}{2,3} {0,2}>? ?:\s")
+            if pat.search(text_between):
                 return False
         text_between = text[first_spans[1]:second_spans[0]]
         if re.search(self.concat_resources["space_between_not_ok"], text_between):
@@ -540,10 +530,7 @@ class Document:
         remove previous phone facts
         add phoneparser made for emails (ContactPhoneParserHighRecall)
         """
-        new_facts = []
-        for fact in facts:
-            if not re.match("PHONE", fact.fact_type):
-                new_facts.append(fact)
+        new_facts = [fact for fact in facts if not re.match("PHONE", fact.fact_type)]
         text = self.get_words()
         phone_numbers = ContactPhoneParserHighRecall(text, months=self.concat_resources["months"]).parse()
         new_facts.extend((number.to_fact(Document.FACT_NAME_PHONE_HIGH_RECALL, self.doc_path) for number in phone_numbers))
