@@ -44,6 +44,14 @@ SUPPORTED_ANALYZERS = (
     "bounded"
 )
 
+# Here we can optimize memory imprint of Stanza by limiting the number of processors.
+# If language not defined here, default will be used.
+STANZA_PROCESSOR_OPTS = {
+    "default": "tokenize,pos,lemma,ner",
+    # no NER for Estonian yet
+    "et": "tokenize,pos,lemma"
+}
+
 
 class MLP:
 
@@ -53,7 +61,8 @@ class MLP:
             default_language_code=DEFAULT_LANG_CODES[0],
             use_default_language_code=True,
             resource_dir: str = DEFAULT_RESOURCE_DIR,
-            logging_level="error"
+            logging_level="error",
+            use_gpu=USE_GPU_FOR_STANZA
     ):
         self.supported_langs = language_codes
         self.logger = logging.getLogger()
@@ -61,6 +70,7 @@ class MLP:
         self.use_default_lang = use_default_language_code
         self.langs_to_transliterate = ["ru"]
         self.resource_dir = resource_dir
+        self.use_gpu=use_gpu
 
         self.resource_dir_pathlib = pathlib.Path(resource_dir)
         self.not_entities_path = self.resource_dir_pathlib / "concatenator" / "not_entities.txt"
@@ -167,8 +177,7 @@ class MLP:
         if not lang:
             lang = self.detect_language(processed_text)
 
-        words = self._get_stanza_tokens(lang, processed_text) if processed_text else []
-        entities = self._get_stanza_ner(lang, processed_text) if processed_text and ("ner" in analyzers) else []
+        words, entities = self._get_stanza_tokens(lang, processed_text) if processed_text else ([], [])
 
         document = Document(
             original_text=processed_text,
@@ -194,31 +203,32 @@ class MLP:
     def _get_stanza_tokens(self, lang: str, raw_text: str):
         # This is a HACK to compensate Stanza errors in tokenizing Russian phone numbers
         # Replaces "-" between digits to "_" so it won't be split into separate tokens (1/2)
+        pat = re.compile(r"(?<=\d)-(?=\d)")
         if lang == "ru":
-            raw_text = re.sub(r"(?<=\d)-(?=\d)", "_", raw_text)
+            raw_text = pat.sub("_", raw_text)
 
         # Separate all the words into a separate list.
 
         pipeline = self.stanza_pipelines[lang](raw_text)
 
         words = []
+        entities = []
+        pip_pat = re.compile(r"(?<=\d)_(?=\d)")
         for sentence in pipeline.sentences:
             for word in sentence.words:
                 # Russian HACK (2/2)
                 # replaces back "#" to "-" between digits.
                 if lang == "ru":
-                    word.text = re.sub(r"(?<=\d)_(?=\d)", "-", word.text)
+                    word.text = pip_pat.sub("-", word.text)
                 words.append(word)
-        return words
+            for entity in sentence.entities:
+                entities.append(entity)
+        return words, entities
 
 
     def _get_stanza_ner(self, lang: str, raw_text: str):
         pipeline = self.stanza_pipelines[lang](raw_text)
-        entities = []
-        for sentence in pipeline.sentences:
-            for entity in sentence.entities:
-                entities.append(entity)
-        return entities
+        return [entity for sentence in pipeline.sentences for entity in sentence.entities]
 
 
     def _load_stanza_pipelines(self, logging_level):
@@ -230,12 +240,23 @@ class MLP:
             stanza_resource_path = pathlib.Path(self.resource_dir) / "stanza"
             stanza_pipelines[lang] = stanza.Pipeline(
                 lang=lang,
-                processors="tokenize,lemma,pos,ner",
+                processors=self._get_stanza_processors(lang),
                 dir=str(stanza_resource_path),
-                use_gpu=USE_GPU_FOR_STANZA,
+                use_gpu=self.use_gpu,
                 logging_level=logging_level
             )
         return stanza_pipelines
+    
+
+    @staticmethod
+    def _get_stanza_processors(lang):
+        """
+        Returns processor options based on language.
+        """
+        if lang not in STANZA_PROCESSOR_OPTS:
+            return STANZA_PROCESSOR_OPTS["default"]
+        else:
+            return STANZA_PROCESSOR_OPTS[lang]
 
 
     def process(self, raw_text: str, analyzers: list = ["all"], lang=None):
@@ -247,6 +268,7 @@ class MLP:
         """
         loaded_analyzers = self._load_analyzers(analyzers, SUPPORTED_ANALYZERS)
         document = self.generate_document(raw_text, loaded_analyzers, lang=lang)
+
         if document:
             for analyzer in loaded_analyzers:
                 # For every analyzer, activate the function that processes it from the
